==> freemedforms-project_0.7.6.orig.tar.gz: freemedforms-0.7.6/plugins/accountplugin/ledger/ledgermanager.h <==
/***************************************************************************
 *  The FreeMedForms project is a set of free, open source medical         *
 *  applications.                                                          *
 *  (C) 2008-2012 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
 *  All rights reserved.                                                   *
 *                                                                         *
 *  The FreeAccount plugins are free, open source FreeMedForms' plugins.   *
 *  (C) 2010-2011 by Pierre-Marie Desombre, MD <pm.desombre@medsyn.fr>     *
 *  and Eric Maeker, MD <eric.maeker@gmail.com>                            *
 *  All rights reserved.                                                   *
 *                                                                         *
 *  This program is free software: you can redistribute it and/or modify   *
 *  it under the terms of the GNU General Public License as published by   *
 *  the Free Software Foundation, either version 3 of the License, or      *
 *  (at your option) any later version.                                    *
 *                                                                         *
 *  This program is distributed in the hope that it will be useful,        *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *  GNU General Public License for more details.                           *
 *                                                                         *
 *  You should have received a copy of the GNU General Public License      *
 *  along with this program (COPYING.FREEMEDFORMS file).                   *
 *  If not, see <http://www.gnu.org/licenses/>.                            *
 ***************************************************************************/
/***************************************************************************
 *  Main Developers : Pierre-Marie DESOMBRE <pm.desombre@medsyn.fr>,      *
 *                     Eric MAEKER, <eric.maeker@gmail.com>                *
 *  Contributors :                                                         *
 *      NAME <MAIL@ADDRESS.COM>                                            *
 ***************************************************************************/
#ifndef LEDGERMANAGER_H
#define LEDGERMANAGER_H
#include "ledgerIO.h"
#include <QObject>
#include <QStandardItemModel>


class LedgerManager : public QObject {
    Q_OBJECT
    enum MovAnalysisValues {
        MOVEMENT_LABEL = 0,
        MOVEMENT_VALUE
        };
    public :
        LedgerManager(QObject * parent);
        ~LedgerManager();
        AccountModel * getModelMonthlyReceiptsAnalysis(QObject * parent,QString & month , QString & year);
        QStandardItemModel * getModelMonthlyAndTypeReceiptsAnalysis(QObject * parent,QString & month,QString & year);
        QStandardItemModel * getModelYearlyAndTypeReceiptsAnalysis(QObject * parent,QString & year);
        
        MovementModel * getModelMonthlyMovementsAnalysis(QObject * parent,QString & month , QString & year);
        QStandardItemModel * getModelMonthlyAndTypeMovementAnalysis(QObject * parent,QString & month,QString & year);
        QStandardItemModel * getModelYearlyAndTypeMovementAnalysis(QObject * parent,QString & year);
        
        QStringList getListOfYears();
        QStringList getListOfMonths();
        double m_sums;
       
};

#endif

==> freemedforms-project_0.9.0.orig.tar.gz: freemedforms-0.9.0/plugins/accountplugin/ledger/ledgermanager.h <==
/***************************************************************************
 *  The FreeMedForms project is a set of free, open source medical         *
 *  applications.                                                          *
 *  (C) 2008-2013 by Eric MAEKER, MD (France) <eric.maeker@gmail.com>      *
 *  All rights reserved.                                                   *
 *                                                                         *
 *  The FreeAccount plugins are free, open source FreeMedForms' plugins.   *
 *  (C) 2010-2011 by Pierre-Marie Desombre, MD <pm.desombre@medsyn.fr>     *
 *  and Eric Maeker, MD <eric.maeker@gmail.com>                            *
 *  All rights reserved.                                                   *
 *                                                                         *
 *  This program is free software: you can redistribute it and/or modify   *
 *  it under the terms of the GNU General Public License as published by   *
 *  the Free Software Foundation, either version 3 of the License, or      *
 *  (at your option) any later version.                                    *
 *                                                                         *
 *  This program is distributed in the hope that it will be useful,        *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
 *  GNU General Public License for more details.                           *
 *                                                                         *
 *  You should have received a copy of the GNU General Public License      *
 *  along with this program (COPYING.FREEMEDFORMS file).                   *
 *  If not, see <http://www.gnu.org/licenses/>.                            *
 ***************************************************************************/
/***************************************************************************
 *  Main Developers:   Pierre-Marie DESOMBRE <pm.desombre@medsyn.fr>,      *
 *                     Eric MAEKER, <eric.maeker@gmail.com>                *
 *  Contributors:                                                          *
 *      NAME <MAIL@ADDRESS.COM>                                            *
 ***************************************************************************/
#ifndef LEDGERMANAGER_H
#define LEDGERMANAGER_H
#include "ledgerio.h"
#include <QObject>
#include <QStandardItemModel>


class LedgerManager : public QObject {
    Q_OBJECT
    enum MovAnalysisValues {
        MOVEMENT_LABEL = 0,
        MOVEMENT_VALUE
        };
    public :
        LedgerManager(QObject * parent);
        ~LedgerManager();
        AccountModel * getModelMonthlyReceiptsAnalysis(QObject * parent,QString & month , QString & year);
        QStandardItemModel * getModelMonthlyAndTypeReceiptsAnalysis(QObject * parent,QString & month,QString & year);
        QStandardItemModel * getModelYearlyAndTypeReceiptsAnalysis(QObject * parent,QString & year);

        MovementModel * getModelMonthlyMovementsAnalysis(QObject * parent,QString & month , QString & year);
        QStandardItemModel * getModelMonthlyAndTypeMovementAnalysis(QObject * parent,QString & month,QString & year);
        QStandardItemModel * getModelYearlyAndTypeMovementAnalysis(QObject * parent,QString & year);

        QStringList getListOfYears();
        QStringList getListOfMonths();
        double getSums();
    private :
        double m_sums;

};

#endif
